@@ -118,7 +118,7 @@ class Resource:
 
 class Gantt:
     """
-    Builds extremely SIMPLE gantt charts.
+    Builds gantt charts.
 
     This is designed to be a basic utility to help estimate schedules and provide a projected
     timeline for a project. As such, not all features like exact start and end dates are supported;
@@ -142,26 +142,26 @@ class Gantt:
 
 
     @classmethod
-    def gantt_from_listdict(cls, name: str, tasks: List[Dict], resources: Dict[str, Resource]=None):
+    def gantt_from_listdict(cls, name: str, tasks_listdict: List[Dict], resources_dict: Dict[str, Resource]=None):
         chart = Gantt(name)
 
-        if resources is None:
-            resources = {}
+        if resources_dict is None:
+            resources_dict = {}
 
         activities = {}
         projects = {}
         dependency_map = {}
 
-        tasks = cls._clean_input_data(tasks)
+        tasks = cls._clean_input_data(tasks_listdict)
 
         # Create all the tasks
         for row in tasks:
             # Add new resources as encountered
             task_resources = []
             for r in row['resources']:
-                if r.name not in resources:
-                    resources[r.name] = r
-                task_resources.append(resources[r.name])
+                if r.name not in resources_dict:
+                    resources_dict[r.name] = r
+                task_resources.append(resources_dict[r.name])
 
             # Add new project as encountered
             project = row['project']
@@ -178,7 +178,7 @@ class Gantt:
                 activities[row['id']] = Task(
                     id=row['id'],
                     name=row['activity'],
-                    duration=row['duration'],
+                    duration=row['duration_days'],
                     resources=task_resources,
                     project=projects[project],
                     dont_start_before_date=row['dont_start_before_date'],
@@ -213,8 +213,8 @@ class Gantt:
                                            if dependency_id in activities.keys()]
 
         # add the resources to the gannt from the resource dict
-        for r in resources:
-            chart.add_resource(resources[r])
+        for r in resources_dict:
+            chart.add_resource(resources_dict[r])
 
         return chart
 
@@ -237,7 +237,7 @@ class Gantt:
 
             # resources
             task_resources = []
-            for r in row['resource'].split('&&'):
+            for r in row['resources'].split('&&'):
                 task_resources.append(Resource(r, color=random_color()))
 
             # Add new project as encountered
@@ -251,8 +251,8 @@ class Gantt:
             sub_activities = eval(row['sub_activities'])
 
             # Duration
-            feature_duration = math.ceil(float(row['duration'])) if row['duration'] is not '' else 1
-            us_duration = sum([math.ceil(float(sub_activity.get('duration', 0)) if sub_activity.get('duration', 0) is not '' else 0)
+            feature_duration = math.ceil(float(row['duration_days'])) if row['duration_days'] is not '' else 1
+            us_duration = sum([math.ceil(float(sub_activity.get('duration_days', 0)) if sub_activity.get('duration_days', 0) is not '' else 0)
                                for sub_activity in sub_activities])
 
             duration = max(feature_duration, us_duration)
@@ -283,7 +283,7 @@ class Gantt:
                 'activity': row['activity'],
                 'state': state,
                 'resources': task_resources,
-                'duration': duration,
+                'duration_days': duration,
                 'project': project,
                 'dont_start_before_date': dont_start_before_date,
                 'actual_start_date': actual_start_date,
@@ -487,16 +487,16 @@ class Gantt:
         df['duration_days'] = [task.duration for task in self.tasks]
         df['expected_duration_remaining'] = [(100 - task.percent_done) * task.duration / 100.0 for task in self.tasks]
         df['resources'] = ['&&'.join([resource.name for resource in task.resources]) for task in self.tasks]
-        df['perc_completed'] = [task.percent_done for task in self.tasks]
+        df['perc_done'] = [task.percent_done for task in self.tasks]
         df['dependencies'] = ['&&'.join([dependency.id for dependency in task.dependencies]) for task in self.tasks]
         df['priority'] = [task.priority for task in self.tasks]
-        df['scheduled_start'] = [task._start_date for task in self.tasks]
-        df['scheduled_end'] = [task.end_date for task in self.tasks]
-        df['status'] = [task.calculated_status.name for task in self.tasks]
+        df['scheduled_start_date'] = [task._start_date for task in self.tasks]
+        df['scheduled_end_date'] = [task.end_date for task in self.tasks]
+        df['state'] = [task.calculated_status.name for task in self.tasks]
         df['sub_activity_summary'] = [task.sub_activity_summary() for task in self.tasks]
         df['sub_activities'] = [task._sub_activities for task in self.tasks]
 
-        df.sort_values(by=['scheduled_start'], ascending=True, inplace=True)
+        df.sort_values(by=['scheduled_start_date'], ascending=True, inplace=True)
 
         return df
 
